% Auto-generated chapter 8 for ibnmajah
% Hadiths in this chapter: 62

\hadithdefcmd{ibnmajah}{1783}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ الْمَكِّيُّ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ بَعَثَ مُعَاذًا إِلَى الْيَمَنِ فَقَالَ ‏ "‏ إِنَّكَ تَأْتِي قَوْمًا أَهْلَ كِتَابٍ فَادْعُهُمْ إِلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ صَدَقَةً فِي أَمْوَالِهِمْ تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ فَتُرَدُّ فِي فُقَرَائِهِمْ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَإِيَّاكَ وَكَرَائِمَ أَمْوَالِهِمْ وَاتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏ ‏.‏\hadithno{1783}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Abbas(RAH) narrated that:the Prophet send Muadh to Yemen, and said: “You are going to some people among the People of the Book. Call them to bear witness that none has the right to be worshipped but Allah, and that I am the messenger of Allah. If they obey that, then tell them that Allah has enjoined upon them five prayers every day and night. If they obey that, then tell them that Allah has enjoined upon them charity (Zakat) from their wealth, to be taken from the rich and given to their poor. If they obey that, then beware of (taking) the best of their wealth. And beware of the supplication of the oppressed, for there is no barrier between and Allah.”}}
\hadithdefcmd{ibnmajah}{1784}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَعْيَنَ، وَجَامِعِ بْنِ أَبِي رَاشِدٍ، سَمِعَا شَقِيقَ بْنَ سَلَمَةَ، يُخْبِرُ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ مَا مِنْ أَحَدٍ لاَ يُؤَدِّي زَكَاةَ مَالِهِ إِلاَّ مُثِّلَ لَهُ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ حَتَّى يُطَوِّقَ عُنُقَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِصْدَاقَهُ مِنْ كِتَابِ اللَّهِ تَعَالَى ‏(‏وَلاَ يَحْسَبَنَّ الَّذِينَ يَبْخَلُونَ بِمَا آتَاهُمُ اللَّهُ مِنْ فَضْلِهِ\}‏ الآيَةَ ‏.‏\hadithno{1784}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Masud (RAH) narrated that:the Messenger of Allah said: “There is no one who does not pay Zakat on his wealth but a bald headed snake will be made to appear to him on the Day of Resurrection, until it encircles his neck.” Then the messenger of Allah recited the following Verse from the Book of Allah the Most High: “And let not those who covetously withhold of that which Allah had bestowed on them of His Bounty(wealth) think that is good for them”}}
\hadithdefcmd{ibnmajah}{1785}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ صَاحِبِ إِبِلٍ وَلاَ غَنَمٍ وَلاَ بَقَرٍ لاَ يُؤَدِّي زَكَاتَهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا كَانَتْ وَأَسْمَنَهُ تَنْطَحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَخْفَافِهَا كُلَّمَا نَفِدَتْ أُخْرَاهَا عَادَتْ عَلَيْهِ أُولاَهَا ‏.‏ حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{1785}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Dharr narrated that:the Messenger of Allah said: “There is no now owner of camels, sheeps or cattle who does not pay Zakat on them, but they will come on the Day of Resurrection as big and as fat as they ever were, butting him with their horns and trampling him with their hooves. Every time the of them has passed, the first of them will come back to him, until judgment is passed upon the people.”}}
\hadithdefcmd{ibnmajah}{1786}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ تَأْتِي الإِبِلُ الَّتِي لَمْ تُعْطِ الْحَقَّ مِنْهَا تَطَأُ صَاحِبَهَا بِأَخْفَافِهَا وَتَأْتِي الْبَقَرُ وَالْغَنَمُ تَطَأُ صَاحِبَهَا بِأَظْلاَفِهَا وَتَنْطَحُهُ بِقُرُونِهَا وَيَأْتِي الْكَنْزُ شُجَاعًا أَقْرَعَ فَيَلْقَى صَاحِبَهُ يَوْمَ الْقِيَامَةِ فَيَفِرُّ مِنْهُ صَاحِبُهُ مَرَّتَيْنِ ثُمَّ يَسْتَقْبِلُهُ فَيَفِرُّ صَاحِبُهُ فَيَقُولُ مَالِي وَلَكَ ‏.‏ فَيَقُولُ أَنَا كَنْزُكَ أَنَا كَنْزُكَ ‏.‏ فَيَتَّقِيهِ بِيَدِهِ فَيَلْقَمُهَا ‏.‏\hadithno{1786}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: “The camels on which the dues (i.e. Zakat) were not paid will come, trampling their owners with their hooves. And cattle and sheep will come and trample at their owners with their hooves and butt them with their horns, And hoarded treasure will come in the form of a bald-headed snale, and will meet its owner on the Day of Resurrection. Its owner will flee from it two time, then it will come to him and he will flee again, and will say: 'What do I have to do with you?' and it will say: 'I am your hoarded treasure, I am your hoarded treasure.' He will try to shield himself with this hand and it will devour it.”}}
\hadithdefcmd{ibnmajah}{1787}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ ابْنِ لَهِيعَةَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي خَالِدُ بْنُ أَسْلَمَ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ قَالَ خَرَجْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ فَلَحِقَهُ أَعْرَابِيٌّ فَقَالَ لَهُ قَوْلُ اللَّهِ ‏\{وَالَّذِينَ يَكْنِزُونَ الذَّهَبَ وَالْفِضَّةَ وَلاَ يُنْفِقُونَهَا فِي سَبِيلِ اللَّهِ\}‏ قَالَ لَهُ ابْنُ عُمَرَ مَنْ كَنَزَهَا فَلَمْ يُؤَدِّ زَكَاتَهَا فَوَيْلٌ لَهُ إِنَّمَا كَانَ هَذَا قَبْلَ أَنْ تُنْزَلَ الزَّكَاةُ فَلَمَّا أُنْزِلَتْ جَعَلَهَا اللَّهُ طَهُورًا لِلأَمْوَالِ ‏.‏ ثُمَّ الْتَفَتَ فَقَالَ مَا أُبَالِي لَوْ كَانَ لِي أُحُدٌ ذَهَبًا أَعْلَمُ عَدَدَهُ وَأُزَكِّيهِ وَأَعْمَلُ فِيهِ بِطَاعَةِ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{1787}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Khalid bin Aslam, the freed slave of Umar bin Khattab, said:“I went out with Abdullah bin Umar, and a Bedouin met him and recited to him the words of Allah: 'And those who hoard up gold and silver (the money, the Zakah of which has not been paid) and spend them not in the way of Allah.' Ibn Umar Said to him: 'The one who hoards it and does not pay Zakat due on it, woe to him. But this was before the (ruling on) Zakat was revealed. When it was revealed, Allah made it a purification of wealth.' Then he turned away and said: 'I do not mind if I have the (the equivalent of) Uhud in gold, provided that I know how much it is and I pay Zakat on it, and I use it in obedience of Allah, the Mighty and Sublime'”}}
\hadithdefcmd{ibnmajah}{1788}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْمَلِكِ، حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ دَرَّاجٍ أَبِي السَّمْحِ، عَنِ ابْنِ حُجَيْرَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أَدَّيْتَ زَكَاةَ مَالِكَ فَقَدْ قَضَيْتَ مَا عَلَيْكَ ‏"‏ ‏.‏\hadithno{1788}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: “When you pay Zakat on your wealth, then you have done what is required to you.”}}
\hadithdefcmd{ibnmajah}{1789}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ شَرِيكٍ، عَنْ أَبِي حَمْزَةَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّهَا سَمِعَتْهُ - تَعْنِي النَّبِيَّ، ـ صلى الله عليه وسلم ـ - يَقُولُ ‏ "‏ لَيْسَ فِي الْمَالِ حَقٌّ سِوَى الزَّكَاةِ ‏"‏ ‏.‏\hadithno{1789}\hadithgrade{Al-Albani: Daif Munkar; Muhammad Fouad Abd al-Baqi: Daif Munkar; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Fatima bint Qais narrated that:she heard him, meaning the Prophet say: “There is nothing due on wealth other then Zakat.”}}
\hadithdefcmd{ibnmajah}{1790}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي قَدْ عَفَوْتُ لَكُمْ عَنْ صَدَقَةِ الْخَيْلِ وَالرَّقِيقِ وَلَكِنْ هَاتُوا رُبُعَ الْعُشُورِ مِنْ كُلِّ أَرْبَعِينَ دِرْهَمًا دِرْهَمًا ‏"‏ ‏.‏\hadithno{1790}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that:the Messenger of Allah said: “I have exempted you from having to pay Zakat on horses and slaves, bring one quarter of one-tenth of every forty Dirhan: one Dirham.”}}
\hadithdefcmd{ibnmajah}{1791}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ وَاقِدٍ، عَنِ ابْنِ عُمَرَ، وَعَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَأْخُذُ مِنْ كُلِّ عِشْرِينَ دِينَارًا فَصَاعِدًا نِصْفَ دِينَارٍ وَمِنَ الأَرْبَعِينَ دِينَارًا دِينَارًا ‏.‏\hadithno{1791}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar and 'Aishah narrated that:that from every twenty Dinar or more. The Prophet used to take half a Dinar and from forty Dinar, one Dinar}}
\hadithdefcmd{ibnmajah}{1792}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، حَدَّثَنَا حَارِثَةُ بْنُ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ زَكَاةَ فِي مَالٍ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ ‏"‏ ‏.‏\hadithno{1792}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that :Aishah said: “I heard the Messenger of Allah(ﷺ) say: 'There is not Zakat on wealth until Hawl (one year) has passed.' ”}}
\hadithdefcmd{ibnmajah}{1793}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي الْوَلِيدُ بْنُ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، وَعَبَّادِ بْنِ تَمِيمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ صَدَقَةَ فِيمَا دُونَ خَمْسَةِ أَوْسَاقٍ مِنَ التَّمْرِ وَلاَ فِيمَا دُونَ خَمْسِ أَوَاقٍ وَلاَ فِيمَا دُونَ خَمْسٍ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{1793}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :he heard the Prophet say: ”There is no sadaqah on anything less than five Awsaq of dates, five Awaq of silver and five camels.”}}
\hadithdefcmd{ibnmajah}{1794}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1794}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:"There is no Sadaqah on less than five camels; there is no Sadaqah on less than five Awaq; and there is no Sadaqah on less than five Awsaq}}
\hadithdefcmd{ibnmajah}{1795}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنْ حَجَّاجِ بْنِ دِينَارٍ، عَنِ الْحَكَمِ، عَنْ حُجَيَّةَ بْنِ عَدِيٍّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ الْعَبَّاسَ، سَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فِي تَعْجِيلِ صَدَقَتِهِ قَبْلَ أَنْ تَحِلَّ فَرَخَّصَ لَهُ فِي ذَلِكَ ‏.‏\hadithno{1795}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abu Talib narrated that :Abbas asked the Prophet about paying his Sadaqah before it is due, and he granted him permission to do that}}
\hadithdefcmd{ibnmajah}{1796}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَتَاهُ الرَّجُلُ بِصَدَقَةِ مَالِهِ صَلَّى عَلَيْهِ فَأَتَيْتُهُ بِصَدَقَةِ مَالِي فَقَالَ ‏ "‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏ ‏.‏\hadithno{1796}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah bin Abu Awfa said:“Whenever a man brought Sadaqah to the Messenger of Allah, he would bless him. I brought him the Sadaqah of my wealth and he said: 'Allhumma, salli ala ali abi awfa(O Allah! Send blessing upon the family of Abu Awfa).' ”}}
\hadithdefcmd{ibnmajah}{1797}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الْبَخْتَرِيِّ بْنِ عُبَيْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَعْطَيْتُمُ الزَّكَاةَ فَلاَ تَنْسَوْا ثَوَابَهَا أَنْ تَقُولُوا اللَّهُمَّ اجْعَلْهَا مَغْنَمًا وَلاَ تَجْعَلْهَا مَغْرَمًا ‏"‏ ‏.‏\hadithno{1797}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah(ﷺ) said: “When you give Zakat, do not forget its reward, and say 'Allahummaj-'alha maghnaman wa la taj-'alha maghrama (O Allah! Make it a gain and do not make it a loss).' ” (Maudu)}}
\hadithdefcmd{ibnmajah}{1798}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ أَقْرَأَنِي سَالِمٌ كِتَابًا كَتَبَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الصَّدَقَاتِ قَبْلَ أَنْ يَتَوَفَّاهُ اللَّهُ فَوَجَدْتُ فِيهِ ‏ "‏ فِي خَمْسٍ مِنَ الإِبِلِ شَاةٌ وَفِي عَشْرٍ شَاتَانِ وَفِي خَمْسَ عَشْرَةَ ثَلاَثُ شِيَاهٍ وَفِي عِشْرِينَ أَرْبَعُ شِيَاهٍ وَفِي خَمْسٍ وَعِشْرِينَ بِنْتُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِنْ لَمْ تُوجَدْ بِنْتُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ فَإِنْ زَادَتْ عَلَى خَمْسٍ وَثَلاَثِينَ وَاحِدَةً فَفِيهَا بِنْتُ لَبُونٍ إِلَى خَمْسَةٍ وَأَرْبَعِينَ فَإِنْ زَادَتْ عَلَى خَمْسٍ وَأَرْبَعِينَ وَاحِدَةً فَفِيهَا حِقَّةٌ إِلَى سِتِّينَ فَإِنْ زَادَتْ عَلَى سِتِّينَ وَاحِدَةً فَفِيهَا جَذَعَةٌ إِلَى خَمْسٍ وَسَبْعِينَ فَإِنْ زَادَتْ عَلَى خَمْسٍ وَسَبْعِينَ وَاحِدَةً فَفِيهَا ابْنَتَا لَبُونٍ إِلَى تِسْعِينَ فَإِنْ زَادَتْ عَلَى تِسْعِينَ وَاحِدَةً فَفِيهَا حِقَّتَانِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا كَثُرَتْ فَفِي كُلِّ خَمْسِينَ حِقَّةٌ وَفِي كُلِّ أَرْبَعِينَ بِنْتُ لَبُونٍ ‏"‏ ‏.‏\hadithno{1798}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Shihab narrated from Salim bin Abdullah, from his father, from the Prophet(ﷺ):Ibn Shihab said: “Salim read to me a letter that the Messenger of Allah had written concerning Sadaqat, before Allah caused him to pass away, in which it was said: 'For five camels one sheep; for ten, two sheep; for twenty, four sheep. For twenty five, a Bint Makhad(a one year old she-camel), up to thirty-five; if there is no Bint Makhad, then a Bin Labun ( a two-year-old male camel). If there are more than thirty-five even one, then a Bint Labun ( a two-year-old she-camel) must be given up to forty-five. If there are more than forty-five, even one, then a Hiqqah (a three-year-old she-camel), up to sixty camels. If there are more than sixty, even one more, then a Jadha'ah ( a four-year-old she-camel) must be given, up to seventy-five. If there are more than seventy-five, even one more, then two Bint Labun must be given, upto ninety. If there are more than ninety, even one more, then two Hiqqah must be given, up to one hundred and twenty. If there are many camels, then for each fifty, one Hiqqah must be given and for each forty a Bint Labun' ”}}
\hadithdefcmd{ibnmajah}{1799}{حَدَّثَنَا مُحَمَّدُ بْنُ عَقِيلِ بْنِ خُوَيْلِدٍ النَّيْسَابُورِيُّ، حَدَّثَنَا حَفْصُ بْنُ عَبْدِ اللَّهِ السُّلَمِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عَمْرِو بْنِ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسٍ مِنَ الإِبِلِ صَدَقَةٌ وَلَيْسَ فِي الأَرْبَعِ شَىْءٌ فَإِذَا بَلَغَتْ خَمْسًا فَفِيهَا شَاةٌ إِلَى أَنْ تَبْلُغَ تِسْعًا فَإِذَا بَلَغَتْ عَشْرًا فَفِيهَا شَاتَانِ إِلَى أَنْ تَبْلُغَ أَرْبَعَ عَشْرَةَ فَإِذَا بَلَغَتْ خَمْسَ عَشْرَةَ فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى أَنْ تَبْلُغَ تِسْعَ عَشْرَةَ فَإِذَا بَلَغَتْ عِشْرِينَ فَفِيهَا أَرْبَعُ شِيَاهٍ إِلَى أَنْ تَبْلُغَ أَرْبَعًا وَعِشْرِينَ فَإِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ فَفِيهَا بِنْتُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِذَا لَمْ تَكُنْ بِنْتُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ فَإِنْ زَادَتْ بَعِيرًا فَفِيهَا بِنْتُ لَبُونٍ إِلَى أَنْ تَبْلُغَ خَمْسًا وَأَرْبَعِينَ فَإِنْ زَادَتْ بَعِيرًا فَفِيهَا حِقَّةٌ إِلَى أَنْ تَبْلُغَ سِتِّينَ فَإِنْ زَادَتْ بَعِيرًا فَفِيهَا جَذَعَةٌ إِلَى أَنْ تَبْلُغَ خَمْسًا وَسَبْعِينَ فَإِنْ زَادَتْ بَعِيرًا فَفِيهَا بِنْتَا لَبُونٍ إِلَى أَنْ تَبْلُغَ تِسْعِينَ فَإِنْ زَادَتْ بَعِيرًا فَفِيهَا حِقَّتَانِ إِلَى أَنْ تَبْلُغَ عِشْرِينَ وَمِائَةً ثُمَّ فِي كُلِّ خَمْسِينَ حِقَّةٌ وَفِي كُلِّ أَرْبَعِينَ بِنْتُ لَبُونٍ ‏"‏ ‏.‏\hadithno{1799}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that:that Abu Sa'eed Al-Khudri said: “The Messenger of Allah said: 'There is no Sadaqah on any less then five camels, or for four. If the number of camels reaches five then one sheep must be given, up to nine. If the number reaches ten, then two sheep must be given, up to fourteen. If the number reaches fifteen, then three sheep must be given, up to nineteen. If the number reaches twenty, then four sheep must be given, up to twenty-four. If the number reaches twenty-five, then a Bint Makhad (a one year old she-camel), must be given up to thirty-five; if there is not Bint Makhad, then a Bin Labun (a two-year-old male camel). If there are more camels then a Bint Labun (a two-year-old she-camel) up to forty-five. If there are more camels then a Hiqqah (a three-year-old she-camel) must be given up to sixty. If there are more camels then a Jadha'ah (a five-year-old she-camel) must be given up to seventy-five. If there are more camels, then two Bint Labun must be given, up to ninety. If there are more camels, then two Hiqqah must be given, up to one hundred and twenty. The for each fifty, one Hiqqah, and for each forty, a Bint Labun.' ”}}
\hadithdefcmd{ibnmajah}{1800}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ مَرْزُوقٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى، حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، كَتَبَ لَهُ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏.‏ هَذِهِ فَرِيضَةُ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى الْمُسْلِمِينَ الَّتِي أَمَرَ اللَّهُ بِهَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَإِنَّ مِنْ أَسْنَانِ الإِبِلِ فِي فَرَائِضِ الْغَنَمِ مَنْ بَلَغَتْ عِنْدَهُ مِنَ الإِبِلِ صَدَقَةُ الْجَذَعَةِ وَلَيْسَ عِنْدَهُ جَذَعَةٌ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيَجْعَلُ مَكَانَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ إِلاَّ بِنْتُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ بِنْتُ لَبُونٍ وَيُعْطِي مَعَهَا شَاتَيْنِ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ لَبُونٍ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ لَبُونٍ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ بِنْتُ مَخَاضٍ فَإِنَّهَا تُقْبَلُ مِنْهُ ابْنَةُ مَخَاضٍ وَيُعْطِي مَعَهَا عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ ‏.‏ وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ مَخَاضٍ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ ابْنَةُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ بِنْتُ لَبُونٍ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ فَمَنْ لَمْ يَكُنْ عِنْدَهُ ابْنَةُ مَخَاضٍ عَلَى وَجْهِهَا وَعِنْدَهُ ابْنُ لَبُونٍ ذَكَرٌ فَإِنَّهُ يُقْبَلُ مِنْهُ وَلَيْسَ مَعَهُ شَىْءٌ ‏.‏\hadithno{1800}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Malik narrated that:Abu Bakr Siddiq wrote to him: “In the name of Allah, the Most Gracious, the Most Merciful. This is the obligation of Sadaqah which the Messenger of Allah enjoined upon the Muslims, as Allah commanded the Messenger of Allah. The ages of camels to be given (in Zakat) may be made up in sheep. So if a man has camels on which the Sadaqah is a Jadha'ah (a four-year-old she-camel) and he does not have a Jadha'ah but he has a Hiqqah (a three year old she-camel), then the Hiqqah should be accepted from him, and two sheep should be given (in addition), if they are readily available, or twenty Dirham. If a man has camels on which the Sadaqah is a Hiqqah, and he only has a Bin Labun( a two-year-old she-camel), then the Bint Labun should be accepted from him, along with two sheep or twenty Dirhams.If a man has camels on which the sadaqah is a Bint Labun, and he does not have one, but he has a Hiqqah, then it should be accepted from him, and the Zakat collector should give him back twenty Dirham or two sheep. If a man has camels on which Sadaqah is a Bint Labun, and he does not have one, but he has a Bint Makhad(a one-year-old she-camel), then the Bint Makhad should be accepted from him, along with twenty Dirham or two sheep. If a man has camels on which the Sadaqah is a Bint Makhad, and he does not have one, but he has a Bint Labun, then the Bint Labun should be accepted from him, and the Zakat collector should give him back twenty Dirhams or two sheep. Whoever does not have a Bint Makhad, but he has a Bint Labun (a two-year-old male camel), then it should be accepted from him and nothing else should be given along with it.' ”}}
\hadithdefcmd{ibnmajah}{1801}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شَرِيكٌ، عَنْ عُثْمَانَ الثَّقَفِيِّ، عَنْ أَبِي لَيْلَى الْكِنْدِيِّ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ جَاءَنَا مُصَدِّقُ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَخَذْتُ بِيَدِهِ وَقَرَأْتُ فِي عَهْدِهِ لاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ ‏.‏ فَأَتَاهُ رَجُلٌ بِنَاقَةٍ عَظِيمَةٍ مُلَمْلَمَةٍ فَأَبَى أَنْ يَأْخُذَهَا فَأَتَاهُ بِأُخْرَى دُونَهَا فَأَخَذَهَا وَقَالَ أَىُّ أَرْضٍ تُقِلُّنِي وَأَىُّ سَمَاءٍ تُظِلُّنِي إِذَا أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَدْ أَخَذْتُ خِيَارَ إِبِلِ رَجُلٍ مُسْلِمٍ ‏.‏\hadithno{1801}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Suwaid bin Ghafalah said: ”The Zakah collector of the Prophet came to us, and I took him by the hand and read in his order: 'Do not gather separate herds and do not separate herd for fear of Sadaqah'. A man brought him a huge, fat she-camel, but he refused to accept it. So he brought him another of lower quality and he accepted it. He said: 'What land would shelter me, if I came to the Messenger of Allah having taken the nest of a Muslim man's camels?' ”}}
\hadithdefcmd{ibnmajah}{1802}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ جَابِرٍ، عَنْ عَامِرٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَرْجِعُ الْمُصَدِّقُ إِلاَّ عَنْ رِضًا ‏"‏ ‏.‏\hadithno{1802}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jarir bin Abdullah narrated that:the Messenger of Allah said: “The Zakat collector should not come back unless the people are pleased with him.”}}
\hadithdefcmd{ibnmajah}{1803}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ عِيسَى الرَّمْلِيُّ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْيَمَنِ وَأَمَرَنِي أَنْ آخُذَ مِنَ الْبَقَرِ مِنْ كُلِّ أَرْبَعِينَ مُسِنَّةً وَمِنْ كُلِّ ثَلاَثِينَ تَبِيعًا أَوْ تَبِيعَةً ‏.‏\hadithno{1803}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Suwa Mu'adh bin Jabal said: “The Messenger of Allah(ﷺ) send me to Yemen and commanded me; for every forty cows, to take a Musinnah and for every thirty, a Tabi or Tabi'ah.”}}
\hadithdefcmd{ibnmajah}{1804}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ خُصَيْفٍ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ فِي ثَلاَثِينَ مِنَ الْبَقَرِ تَبِيعٌ أَوْ تَبِيعَةٌ وَفِي أَرْبَعِينَ مُسِنَّةٌ ‏"‏ ‏.‏\hadithno{1804}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abdullah narrated that:the Prophet said: “For every thirty cattle, Tabi or Tabi'ah and for every forty a Musinnah.”}}
\hadithdefcmd{ibnmajah}{1805}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ أَقْرَأَنِي سَالِمٌ كِتَابًا كَتَبَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الصَّدَقَاتِ قَبْلَ أَنْ يَتَوَفَّاهُ اللَّهُ فَوَجَدْتُ فِيهِ ‏"‏ فِي أَرْبَعِينَ شَاةً شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا شَاتَانِ إِلَى مِائَتَيْنِ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةٍ فَإِذَا كَثُرَتْ فَفِي كُلِّ مِائَةٍ شَاةٌ ‏"‏ ‏.‏ وَوَجَدْتُ فِيهِ ‏"‏ لاَ يُجْمَعُ بَيْنَ مَتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ ‏"‏ ‏.‏ وَوَجَدْتُ فِيهِ ‏"‏ لاَ يُؤْخَذُ فِي الصَّدَقَةِ تَيْسٌ وَلاَ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ ‏"‏ ‏.‏\hadithno{1805}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Shihab, from Salim bin Abdullah, from his father, from the Messenger of Allah:Salim said: “My father read to me a letter that the Messenger of Allah (ﷺ) had written about Sadaqat before Allah caused him to pass away. I read in it: 'For forty sheep, one sheep, up to one hundred and twenty. If there is more than that - even one - then two sheep, up to two hundred, If there is one more than that - even one = then three sheep, up to three hundred. If there are many sheep, then for each hundred, one sheep.' And I read in it: 'Separate flocks should not be combined, and a combined flock should not be separated.' And I read in it: 'And a male goat should not be taken for Sadaqah, nor a decrepit nor defective animal.' ”}}
\hadithdefcmd{ibnmajah}{1806}{حَدَّثَنَا أَبُو بَدْرٍ، عَبَّادُ بْنُ الْوَلِيدِ حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تُؤْخَذُ صَدَقَاتُ الْمُسْلِمِينَ عَلَى مِيَاهِهِمْ ‏"‏ ‏.‏\hadithno{1806}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated that:the Messenger of Allah said: “The Sadaqah of Muslims should be taken at their watering places.”}}
\hadithdefcmd{ibnmajah}{1807}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هِنْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏ "‏ فِي أَرْبَعِينَ شَاةً شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا شَاتَانِ إِلَى مِائَتَيْنِ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةٍ فَإِذَا زَادَتْ فَفِي كُلِّ مِائَةٍ شَاةٌ لاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ خَشْيَةَ الصَّدَقَةِ وَكُلُّ خَلِيطَيْنِ يَتَرَاجَعَانِ بِالسَّوِيَّةِ وَلَيْسَ لِلْمُصَدِّقِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ وَلاَ تَيْسٌ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ ‏"‏ ‏.‏\hadithno{1807}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated that:the Messenger of Allah said: “For forty sheep, one sheep up to one hundred and twenty. If there is one more. Then two sheep, up to two hundred. If there is one more, then three sheep, up to three hundred. If there are more than that, then for every hundred one sheep. Do not separate combined flock and do not combine separate flocks for fear of Sadaqah. Each partner (who has a share in the flock) should pay in proportion to his shares. And the Zakat collector should not accept any decrepit or defective animal, nor any male goat, unless he wishes to.”}}
\hadithdefcmd{ibnmajah}{1808}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُعْتَدِي فِي الصَّدَقَةِ كَمَانِعِهَا ‏"‏ ‏.‏\hadithno{1808}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that:the Messenger of Allah said: “The one who is unjust in Sadaqah is like the one who withholds it.”}}
\hadithdefcmd{ibnmajah}{1809}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، وَيُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْعَامِلُ عَلَى الصَّدَقَةِ بِالْحَقِّ كَالْغَازِي فِي سَبِيلِ اللَّهِ حَتَّى يَرْجِعَ إِلَى بَيْتِهِ ‏"‏ ‏.‏\hadithno{1809}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Rafi bin Khadij said: “I heard the Messenger of Allah say: 'The person who is appointed to collect the Sadaqah - who does so with sincerity and fairness is like one who foes out to fight for the sake of Allah, until he returns to the house.' ”}}
\hadithdefcmd{ibnmajah}{1810}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْمِصْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ مُوسَى بْنَ جُبَيْرٍ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحُبَابِ الأَنْصَارِيَّ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ أُنَيْسٍ حَدَّثَهُ أَنَّهُ، تَذَاكَرَ هُوَ وَعُمَرُ بْنُ الْخَطَّابِ يَوْمًا الصَّدَقَةَ فَقَالَ عُمَرُ أَلَمْ تَسْمَعْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ يَذْكُرُ غُلُولَ الصَّدَقَةِ ‏ "‏ أَنَّهُ مَنْ غَلَّ مِنْهَا بَعِيرًا أَوْ شَاةً أُتِيَ بِهِ يَوْمَ الْقِيَامَةِ يَحْمِلُهُ ‏"‏ ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ بْنُ أُنَيْسٍ بَلَى ‏.‏\hadithno{1810}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Unais said that he and Umar bin Khattab were speaking about Sadaqah one day, and:Umar bin Khattab said: “Did you not hear the Messenger of Allah when he mentioned Ghulul with the Sadaqah (and said): 'Whoever steals a camel or a sheep from it, he will be brought carrying it on the Day of Resurrection?' ” Abdullah bin Unais said: “Yes.”}}
\hadithdefcmd{ibnmajah}{1811}{حَدَّثَنَا أَبُو بَدْرٍ، عَبَّادُ بْنُ الْوَلِيدِ حَدَّثَنَا أَبُو عَتَّابٍ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَطَاءٍ، مَوْلَى عِمْرَانَ حَدَّثَنِي أَبِي أَنَّ عِمْرَانَ بْنَ الْحُصَيْنِ، اسْتُعْمِلَ عَلَى الصَّدَقَةِ فَلَمَّا رَجَعَ قِيلَ لَهُ أَيْنَ الْمَالُ قَالَ وَلِلْمَالِ أَرْسَلْتَنِي أَخَذْنَاهُ مِنْ حَيْثُ كُنَّا نَأْخُذُهُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَوَضَعْنَاهُ حَيْثُ كُنَّا نَضَعُهُ ‏.‏\hadithno{1811}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibrahim bin Ata, the freed slave of Imran bin Husain, said:“My father told me that 'Imran bin Hussain was appointed to collect the Sadaqah. When he came back, it was said to him: 'Where is the wealth?' He said: 'Was it for wealth that you sent me? We took it from where we used to take it at the time of the Messenger of Allah, and we distributed it where we used to distribute it.' ”}}
\hadithdefcmd{ibnmajah}{1812}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فِي فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1812}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Huraitah narrated that:the Messenger of Allah said: “The Muslim is not obliged to pay Sadaqah on his slave not his horse.”}}
\hadithdefcmd{ibnmajah}{1813}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَجَوَّزْتُ لَكُمْ عَنْ صَدَقَةِ الْخَيْلِ وَالرَّقِيقِ ‏"‏ ‏.‏\hadithno{1813}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that:the Messenger of Allah said: “I have exempted you from having to pay Sadaqah on horses and slaves.”}}
\hadithdefcmd{ibnmajah}{1814}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَعَثَهُ إِلَى الْيَمَنِ وَقَالَ لَهُ ‏ "‏ خُذِ الْحَبَّ مِنَ الْحَبِّ وَالشَّاةَ مِنَ الْغَنَمِ وَالْبَعِيرَ مِنَ الإِبِلِ وَالْبَقَرَةَ مِنَ الْبَقَرِ ‏"‏ ‏.‏\hadithno{1814}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal narrated that:the Messenger of Allah sent him to Yemen and said to him: “Take grains from grains, sheep from sheep, camels from camels and cows from cows”}}
\hadithdefcmd{ibnmajah}{1815}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ إِنَّمَا سَنَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الزَّكَاةَ فِي هَذِهِ الْخَمْسَةِ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالتَّمْرِ وَالزَّبِيبِ وَالذُّرَةِ ‏.‏\hadithno{1815}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Amr bin:Shu'aib, form his father, that his grandfather said: “The Messenger of Allah only prescribed Zakat on these five things: wheat, barley, dates, raisins and corn.”}}
\hadithdefcmd{ibnmajah}{1816}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى أَبُو مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا عَاصِمُ بْنُ عَبْدِ الْعَزِيزِ بْنِ عَاصِمٍ، حَدَّثَنَا الْحَارِثُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي ذُبَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالْعُيُونُ الْعُشْرُ وَفِيمَا سُقِيَ بِالنَّضْحِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{1816}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah (ﷺ) said: “For crops that are irrigated by the sky (i.e. rain) and springs, one-tenth. For those that are irrigated by watering, one half of one-tenth.”}}
\hadithdefcmd{ibnmajah}{1817}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الْمِصْرِيُّ أَبُو جَعْفَرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالأَنْهَارُ وَالْعُيُونُ أَوْ كَانَ بَعْلاً الْعُشْرُ وَفِيمَا سُقِيَ بِالسَّوَانِي نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{1817}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Salim narrated that:that his Father said: “I heard the Messenger of Allah say: 'For whatever is irrigated by the sky, rivers and springs, or draws up water from deep roots, one-tenth. For whatever is irrigated by animals (i.e. by artificial means) one half of one-tenth.' ”}}
\hadithdefcmd{ibnmajah}{1818}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيِّ بْنِ عَفَّانَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْيَمَنِ وَأَمَرَنِي أَنْ آخُذَ مِمَّا سَقَتِ السَّمَاءُ أَوْ سُقِيَ بَعْلاً الْعُشْرَ وَمَا سُقِيَ بِالدَّوَالِي نِصْفَ الْعُشْرِ ‏.‏ قَالَ يَحْيَى بْنُ آدَمَ الْبَعْلُ وَالْعَثَرِيُّ وَالْعَذْىُ هُوَ الَّذِي يُسْقَى بِمَاءِ السَّمَاءِ ‏.‏ وَالْعَثَرِيُّ مَا يُزْرَعُ لِلسَّحَابِ وَلِلْمَطَرِ خَاصَّةً لَيْسَ يُصِيبُهُ إِلاَّ مَاءُ الْمَطَرِ ‏.‏ وَالْبَعْلُ مَا كَانَ مِنَ الْكُرُومِ قَدْ ذَهَبَتْ عُرُوقُهُ فِي الأَرْضِ إِلَى الْمَاءِ فَلاَ يَحْتَاجُ إِلَى السَّقْىِ الْخَمْسَ سِنِينَ أَوِ السِّتَّ يَحْتَمِلُ تَرْكَ السَّقْىِ فَهَذَا الْبَعْلُ ‏.‏ وَالسَّيْلُ مَاءُ الْوَادِي إِذَا سَالَ ‏.‏ وَالْغَيْلُ سَيْلٌ دُونَ سَيْلٍ ‏.‏\hadithno{1818}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Mu'adh bin Jabal said: “The Messenger of Allah (ﷺ) sent me to Yemen and commanded me to take one-tenth of that which was irrigated by deep roots, and to take one half of one-tenth of that which was irrigated by means of buckets.”}}
\hadithdefcmd{ibnmajah}{1819}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، وَالزُّبَيْرُ بْنُ بَكَّارٍ، قَالاَ حَدَّثَنَا ابْنُ نَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ صَالِحٍ التَّمَّارُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَتَّابِ بْنِ أَسِيدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَبْعَثُ عَلَى النَّاسِ مَنْ يَخْرُصُ عَلَيْهِمْ كُرُومَهُمْ وَثِمَارَهُمْ ‏.‏\hadithno{1819}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Attab bin Asid narrated that:the Prophet used to send to the people one who would assess their vineyards and fruits}}
\hadithdefcmd{ibnmajah}{1820}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، حَدَّثَنَا عُمَرُ بْنُ أَيُّوبَ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ حِينَ افْتَتَحَ خَيْبَرَ اشْتَرَطَ عَلَيْهِمْ أَنَّ لَهُ الأَرْضَ وَكُلَّ صَفْرَاءَ وَبَيْضَاءَ ‏.‏ يَعْنِي الذَّهَبَ وَالْفِضَّةَ ‏.‏ وَقَالَ لَهُ أَهْلُ خَيْبَرَ نَحْنُ أَعْلَمُ بِالأَرْضِ فَأَعْطِنَاهَا عَلَى أَنْ نَعْمَلَهَا وَيَكُونَ لَنَا نِصْفُ الثَّمَرَةِ وَلَكُمْ نِصْفُهَا ‏.‏ فَزَعَمَ أَنَّهُ أَعْطَاهُمْ عَلَى ذَلِكَ فَلَمَّا كَانَ حِينَ يُصْرَمُ النَّخْلُ بَعَثَ إِلَيْهِمُ ابْنَ رَوَاحَةَ فَحَزَرَ النَّخْلَ وَهُوَ الَّذِي يَدْعُونَهُ أَهْلُ الْمَدِينَةِ الْخَرْصَ فَقَالَ فِي ذَا كَذَا وَكَذَا ‏.‏ فَقَالُوا أَكْثَرْتَ عَلَيْنَا يَا ابْنَ رَوَاحَةَ ‏.‏ فَقَالَ فَأَنَا أَحْزُرُ النَّخْلَ وَأُعْطِيكُمْ نِصْفَ الَّذِي قُلْتُ ‏.‏ قَالَ فَقَالُوا هَذَا الْحَقُّ وَبِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ ‏.‏ فَقَالُوا قَدْ رَضِينَا أَنْ نَأْخُذَ بِالَّذِي قُلْتَ ‏.‏\hadithno{1820}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that:when the Prophet conquered Khaibar, he stipulated that the land, and all the yellow and white, meaning gold and silver belonged to him. The people of Khaibar said to him: “We know the land better, so give it to us so that we may work the land, and you will have half of its produce and we will have half.” He maintained that, he gave it to them on that basis. When the time for the date harvest came, he sent Ibn Rawahah to them. He assesses the date palms, and he said: “For this tree, such and such (amount).” They said: “You are demanding too much of us, O Ibn Rawahah!” He said: “This is my assessment and I will give you half of what I say.” They said: “This is fair, and fairness is what haven and earth are based on.” They said: “We Agree to take (accept) what you say.”}}
\hadithdefcmd{ibnmajah}{1821}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، حَدَّثَنِي صَالِحُ بْنُ أَبِي عَرِيبٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَدْ عَلَّقَ رَجُلٌ قِنَاءً أَوْ قِنْوًا وَبِيَدِهِ عَصًا فَجَعَلَ يَطْعَنُ بِذَلِكَ يُدَقْدِقُ فِي ذَلِكَ الْقِنْوِ وَيَقُولُ ‏ "‏ لَوْ شَاءَ رَبُّ هَذِهِ الصَّدَقَةِ تَصَدَّقَ بِأَطْيَبَ مِنْهَا إِنَّ رَبَّ هَذِهِ الصَّدَقَةِ يَأْكُلُ الْحَشَفَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1821}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Awf bin Malik Al-Ashja'i said: “The Messenger of Allah went out, and a man had hung up one or more bunches of dates. He (the Prophet) had a stick in his hand and he started hitting that bunch of dates repeatedly, saying: 'If the owner of these dates wanted to give in charity, he should have given something better than these. The owner of this charity will eat rotten and shriveled dates on the Day of Resurrection.' ”}}
\hadithdefcmd{ibnmajah}{1822}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ الْعَنْقَزِيُّ، حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ، عَنِ السُّدِّيِّ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، فِي قَوْلِهِ سُبْحَانَهُ ‏\{‏وَمِمَّا أَخْرَجْنَا لَكُمْ مِنَ الأَرْضِ وَلاَ تَيَمَّمُوا الْخَبِيثَ مِنْهُ تُنْفِقُونَ\}‏ ‏.‏ قَالَ نَزَلَتْ فِي الأَنْصَارِ كَانَتِ الأَنْصَارُ تُخْرِجُ إِذَا كَانَ جِدَادُ النَّخْلِ مِنْ حِيطَانِهَا أَقْنَاءَ الْبُسْرِ فَيُعَلِّقُونَهُ عَلَى حَبْلٍ بَيْنَ أُسْطُوَانَتَيْنِ فِي مَسْجِدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَيَأْكُلُ مِنْهُ فُقَرَاءُ الْمُهَاجِرِينَ فَيَعْمِدُ أَحَدُهُمْ فَيُدْخِلُ قِنْوَ الْحَشَفِ يَظُنُّ أَنَّهُ جَائِزٌ فِي كَثْرَةِ مَا يُوضَعُ مِنَ الأَقْنَاءِ فَنَزَلَ فِيمَنْ فَعَلَ ذَلِكَ ‏\{وَلاَ تَيَمَّمُوا الْخَبِيثَ مِنْهُ تُنْفِقُونَ\}‏ ‏.‏ يَقُولُ لاَ تَعْمِدُوا لِلْحَشَفِ مِنْهُ تُنْفِقُونَ ‏.‏ ‏\{وَلَسْتُمْ بِآخِذِيهِ إِلاَّ أَنْ تُغْمِضُوا فِيهِ \}‏ يَقُولُ لَوْ أُهْدِيَ لَكُمْ مَا قَبِلْتُمُوهُ إِلاَّ عَلَى اسْتِحْيَاءٍ مِنْ صَاحِبِهِ غَيْظًا أَنَّهُ بَعَثَ إِلَيْكُمْ مَا لَمْ يَكُنْ لَكُمْ فِيهِ حَاجَةٌ وَاعْلَمُوا أَنَّ اللَّهَ غَنِيٌّ عَنْ صَدَقَاتِكُمْ ‏.‏\hadithno{1822}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Bara bin Azib said concerning the Verse: “And of that which We have priduced from the earth for you, and don not aim at that which is bad to spend from it. ” [Al-Baqarah 2:267] “This was revealed concerning the Ansar. At the time of the new date-palm harvest, they would take a bunch of dates that were beginning to ripen and hang it on a rope between two of the pillars in the mosque of the Messenger of Allah (ﷺ), and the poor emigrants would eat from it.” One of them deliberately mixed a bunch containing rotten and shriveled dates, and thought this was permissible because of the large number of dates that had been put there. So the following was revealed about the one who did that: '… and do not aim at that which is bad to spend from it'. Meaning do not seek out the rotten and shriveled dates to give in charity: '…(thought) you would not accept it save if you close your eyes and tolerate therein.' Meaning, if you were given this as a gift you would only accept it because you felt embarrassed, and you would get angry that he had sent something of which you have no need. And know that Allah has no need of your charity.”}}
\hadithdefcmd{ibnmajah}{1823}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ أَبِي سَيَّارَةَ الْمُتَعِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي نَحْلاً ‏.‏ قَالَ ‏ "‏ أَدِّ الْعُشْرَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ احْمِهَا لِي ‏.‏ فَحَمَاهَا لِي ‏.‏\hadithno{1823}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Abu Sayyarah Al-Muta said: “I said: 'O Messenger of Allah! I have bees.' He said: 'Give one-tenth.' I said: 'O Messenger of Allah!' Protect it for me.' And he protected it for me.”}}
\hadithdefcmd{ibnmajah}{1824}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا نُعَيْمُ بْنُ حَمَّادٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ أَخَذَ مِنَ الْعَسَلِ الْعُشْرَ ‏.‏\hadithno{1824}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr narrated that:the Prophet took one-tenth of honey (as Zakat)}}
\hadithdefcmd{ibnmajah}{1825}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِزَكَاةِ الْفِطْرِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏ قَالَ عَبْدُ اللَّهِ فَجَعَلَ النَّاسُ عِدْلَهُ مُدَّيْنِ مِنْ حِنْطَةٍ ‏.‏\hadithno{1825}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Umar narrated that:the Messenger of Allah enjoined Zakatul-Fitr, one Sa of dates or one Sa of barley.Abdullah said: The people made two Mudd (equal to half of a Sa) of wheat as its equivalent}}
\hadithdefcmd{ibnmajah}{1826}{حَدَّثَنَا حَفْصُ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَدَقَةَ الْفِطْرِ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{1826}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Umar said: “The Messenger of Allah enjoined Sadaqatul-Fitr, one Sa, of barley or one Sa of dates for every Muslim, free or slave, male or female.”}}
\hadithdefcmd{ibnmajah}{1827}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو يَزِيدَ الْخَوْلاَنِيُّ، عَنْ سَيَّارِ بْنِ عَبْدِ الرَّحْمَنِ الصَّدَفِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فَرَضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ زَكَاةَ الْفِطْرِ طُهْرَةً لِلصَّائِمِ مِنَ اللَّغْوِ وَالرَّفَثِ وَطُعْمَةً لِلْمَسَاكِينِ فَمَنْ أَدَّاهَا قَبْلَ الصَّلاَةِ فَهِيَ زَكَاةٌ مَقْبُولَةٌ وَمَنْ أَدَّاهَا بَعْدَ الصَّلاَةِ فَهِيَ صَدَقَةٌ مِنَ الصَّدَقَاتِ ‏.‏\hadithno{1827}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Ibn Abbas said: “The Messenger of Allah (ﷺ) enjoined Zakatul-Fitr as a purification for the fasting person from idle talk and obscenities, and to feed the poor. Whoever pays it before the (Eid) prayer, it is an accepted Zakah, and whoever pays it after the prayer, it is (ordinary) charity.”}}
\hadithdefcmd{ibnmajah}{1828}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ أَبِي عَمَّارٍ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِصَدَقَةِ الْفِطْرِ قَبْلَ أَنْ تُنْزَلَ الزَّكَاةُ فَلَمَّا نَزَلَتِ الزَّكَاةُ لَمْ يَأْمُرْنَا وَلَمْ يَنْهَنَا وَنَحْنُ نَفْعَلُهُ ‏.‏\hadithno{1828}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that:Qais bin Sa'ad said: “The Messenger of Allah (ﷺ) enjoined Sadaqatul-Fitr upon is before (the command of) Zakat was revealed. He neither ordered us (to pay) nor forbade us (from paying it), so we did it.”}}
\hadithdefcmd{ibnmajah}{1829}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ دَاوُدَ بْنِ قَيْسٍ الْفَرَّاءِ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَاعًا مِنْ طَعَامٍ صَاعًا مِنْ تَمْرٍ صَاعًا مِنْ شَعِيرٍ صَاعًا مِنْ أَقِطٍ صَاعًا مِنْ زَبِيبٍ فَلَمْ نَزَلْ كَذَلِكَ حَتَّى قَدِمَ عَلَيْنَا مُعَاوِيَةُ الْمَدِينَةَ فَكَانَ فِيمَا كَلَّمَ بِهِ النَّاسَ أَنْ قَالَ لاَ أُرَى مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ إِلاَّ تَعْدِلُ صَاعًا مِنْ هَذَا ‏.‏ فَأَخَذَ النَّاسُ بِذَلِكَ ‏.‏ قَالَ أَبُو سَعِيدٍ لاَ أَزَالُ أُخْرِجُهُ كَمَا كُنْتُ أُخْرِجُهُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَبَدًا مَا عِشْتُ ‏.‏\hadithno{1829}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Abu Sa'eed Al-Khudri said: “We used to pay Zakatul-Fitr when the Messenger of Allah was among us, one Sa of food, one Sa of dates, one Sa of barley, one Sa of sun-baked cottage cheese, one Sa of raisins. We continued to do that until Mu'awiyah came to us in Al-Madinah. One of the things he said to the people was: 'I think that two Mudd wheat from Sham is equivalent to one Sa of this (i.e. dates).' So the people followed that.”Abu Sa'eed said: “I'll continue to pay it as I used to pay it at the time of Messenger of Allah for as long as I live.”}}
\hadithdefcmd{ibnmajah}{1830}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارٍ الْمُؤَذِّنِ، حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، عَنْ عَمَّارِ بْنِ سَعْدٍ، مُؤَذِّنِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِصَدَقَةِ الْفِطْرِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ سُلْتٍ ‏.‏\hadithno{1830}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ammar bin Sa'eed, the Mu'adhdhin of the Messenger of Allah from his father,:that the Messenger of Allah enjoined Sadaqatul-Fitr, one Sa of dates, one Sa of barley, or one Sa of Sult (a kind of barley without skin on it, resembling wheat)}}
\hadithdefcmd{ibnmajah}{1831}{حَدَّثَنَا الْحُسَيْنُ بْنُ جُنَيْدٍ الدَّامَغَانِيُّ، حَدَّثَنَا عَتَّابُ بْنُ زِيَادٍ الْمَرْوَزِيُّ، حَدَّثَنَا أَبُو حَمْزَةَ، قَالَ سَمِعْتُ مُغِيرَةَ الأَزْدِيَّ، يُحَدِّثُ عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ حَيَّانَ الأَعْرَجِ، عَنِ الْعَلاَءِ بْنِ الْحَضْرَمِيِّ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْبَحْرَيْنِ - أَوْ إِلَى هَجَرَ - فَكُنْتُ آتِي الْحَائِطَ يَكُونُ بَيْنَ الإِخْوَةِ يُسْلِمُ أَحَدُهُمْ فَآخُذُ مِنَ الْمُسْلِمِ الْعُشْرَ وَمِنَ الْمُشْرِكِ الْخَرَاجَ ‏.‏\hadithno{1831}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated:that Ala bin Hadrami said: “The Messenger of Allah sent me to Bahrain or Hajar. I used to go to a garden that was shared by some brothers, one of whom had become Muslim. I would take the Ushr (one-tenth of the harvest) from the Muslim, and Kharaj from the Mushrik.”}}
\hadithdefcmd{ibnmajah}{1832}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ إِدْرِيسَ الأَوْدِيِّ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي سَعِيدٍ، رَفَعَهُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْوَسْقُ سِتُّونَ صَاعًا ‏"‏ ‏.‏\hadithno{1832}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated and attributed to the Prophet:“A Wasq is sixty Sa.”}}
\hadithdefcmd{ibnmajah}{1833}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، وَأَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْوَسْقُ سِتُّونَ صَاعًا ‏"‏ ‏.‏\hadithno{1833}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Jabir bin Abdullah said: “The Messenger of Allah said: 'A Wasq is sixty Sa.' ”}}
\hadithdefcmd{ibnmajah}{1834}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ بْنِ الْمُصْطَلِقِ ابْنِ أَخِي، زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَيُجْزِئُ عَنِّي مِنَ الصَّدَقَةِ النَّفَقَةُ عَلَى زَوْجِي وَأَيْتَامٍ فِي حِجْرِي قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَهَا أَجْرَانِ أَجْرُ الصَّدَقَةِ وَأَجْرُ الْقَرَابَةِ ‏"‏ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ ابْنِ أَخِي، زَيْنَبَ عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1834}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Zainab, the wife of Abdullah said: “I asked the Messenger of Allah: 'Will it be accepted as charity on my part if I spend on my husband and the orphans in my care?' The Messenger of Allah said: 'She will have two rewards, the reward for charity and the reward for upholding ties of kinship.'”}}
\hadithdefcmd{ibnmajah}{1835}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالصَّدَقَةِ ‏.‏ فَقَالَتْ زَيْنَبُ امْرَأَةُ عَبْدِ اللَّهِ أَيُجْزِينِي مِنَ الصَّدَقَةِ أَنْ أَتَصَدَّقَ عَلَى زَوْجِي وَهُوَ فَقِيرٌ وَبَنِي أَخٍ لِي أَيْتَامٍ وَأَنَا أُنْفِقُ عَلَيْهِمْ هَكَذَا وَهَكَذَا وَعَلَى كُلِّ حَالٍ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَكَانَتْ صَنَاعَ الْيَدَيْنِ ‏.‏\hadithno{1835}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that:Umm Salamah said: “The Messenger of Allah enjoined charity upon us. Zainab, the wife of Abdullah said: 'Will it be accepted as charity on my part if I give charity to my husband who is poor, and to the children of a brother of mine who are orphans, spending such and such on them, and in all circumstances?' He said: 'Yes.'”}}
\hadithdefcmd{ibnmajah}{1836}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ الأَوْدِيُّ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لأَنْ يَأْخُذَ أَحَدُكُمْ أَحْبُلَهُ فَيَأْتِيَ الْجَبَلَ فَيَجِيءَ بِحُزْمَةِ حَطَبٍ عَلَى ظَهْرِهِ فَيَبِيعَهَا فَيَسْتَغْنِيَ بِثَمَنِهَا خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ النَّاسَ أَعْطَوْهُ أَوْ مَنَعُوهُ ‏"‏ ‏.‏\hadithno{1836}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Hisham bin Urwah, from his father, that:his grandfather said: “The Messenger of Allah said: 'If one of you were to take his rope (or ropes) and go to the mountains, and bring a bundle of firewood on his back to sell, and thus become independent of means, that would be better for him than begging from people who may either give him something or not give him anything.'”}}
\hadithdefcmd{ibnmajah}{1837}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ يَتَقَبَّلُ لِي بِوَاحِدَةٍ وَأَتَقَبَّلُ لَهُ بِالْجَنَّةِ ‏"‏ قُلْتُ أَنَا ‏.‏ قَالَ ‏"‏ لاَ تَسْأَلِ النَّاسَ شَيْئًا ‏"‏ ‏.‏ قَالَ فَكَانَ ثَوْبَانُ يَقَعُ سَوْطُهُ وَهُوَ رَاكِبٌ فَلاَ يَقُولُ لأَحَدٍ نَاوِلْنِيهِ حَتَّى يَنْزِلَ فَيَأْخُذَهُ ‏.‏\hadithno{1837}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin Yazid narrated that:Thawban said: “The Messenger of Allah said: 'Who will commit himself to one thing, I will guarantee him paradise?' I said: 'I will.' He said: 'Do not ask people for anything.' So Thawban would drop his whip while he was on his mount, and he would not say to anyone: 'Get that for me' rather he would dismount and grab it.”}}
\hadithdefcmd{ibnmajah}{1838}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ سَأَلَ النَّاسَ أَمْوَالَهُمْ تَكَثُّرًا فَإِنَّمَا يَسْأَلُ جَمْرَ جَهَنَّمَ فَلْيَسْتَقِلَّ مِنْهُ أَوْ لِيُكْثِرْ ‏"‏ ‏.‏\hadithno{1838}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah(ﷺ) said: “Whoever begs from people so as to accumulate more riches, he is asking for alive coal from hell, so let him ask for a lot or a little.”}}
\hadithdefcmd{ibnmajah}{1839}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏\hadithno{1839}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: “Charity is not permissible for a rich person, or for one who is strong and healthy. ”}}
\hadithdefcmd{ibnmajah}{1840}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ سَأَلَ وَلَهُ مَا يُغْنِيهِ جَاءَتْ مَسْأَلَتُهُ يَوْمَ الْقِيَامَةِ خُدُوشًا أَوْ خُمُوشًا أَوْ كُدُوحًا فِي وَجْهِهِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا يُغْنِيهِ قَالَ ‏"‏ خَمْسُونَ دِرْهَمًا أَوْ قِيمَتُهَا مِنَ الذَّهَبِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ لِسُفْيَانَ إِنَّ شُعْبَةَ لاَ يُحَدِّثُ عَنْ حَكِيمِ بْنِ جُبَيْرٍ ‏.‏ فَقَالَ سُفْيَانُ قَدْ حَدَّثَنَاهُ زُبَيْدٌ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ ‏.‏\hadithno{1840}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that:the Messenger of Allah said: “Whoever begs when he has enough to suffice him, his begging will come on the Day of Resurrection like lacerations on his face. ” It was said: “O Messenger of Allah, what is sufficient for him?” He said: “Fifty Dirham or their value in gold.”}}
\hadithdefcmd{ibnmajah}{1841}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ إِلاَّ لِخَمْسَةٍ لِعَامِلٍ عَلَيْهَا أَوْ لِغَازٍ فِي سَبِيلِ اللَّهِ أَوْ لِغَنِيٍّ اشْتَرَاهَا بِمَالِهِ أَوْ فَقِيرٍ تُصُدِّقَ عَلَيْهِ فَأَهْدَاهَا لِغَنِيٍّ أَوْ غَارِمٍ ‏"‏ ‏.‏\hadithno{1841}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:the Messenger of Allah said: “Charity is not permissible for a rich man except in five cases: One who is appointed to collect it, a warrior fighting in the cause of Allah, a rich man who buys it with his own money, a poor man who receives the charity and gives it as a gift to a rich man, and a debtor.”}}
\hadithdefcmd{ibnmajah}{1842}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ سَعِيدِ بْنِ يَسَارٍ، ‏.‏ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا تَصَدَّقَ أَحَدٌ بِصَدَقَةٍ مِنْ طَيِّبٍ وَلاَ يَقْبَلُ اللَّهُ إِلاَّ الطَّيِّبَ إِلاَّ أَخَذَهَا الرَّحْمَنُ بِيَمِينِهِ وَإِنْ كَانَتْ تَمْرَةً فَتَرْبُو فِي كَفِّ الرَّحْمَنِ حَتَّى تَكُونَ أَعْظَمَ مِنَ الْجَبَلِ وَيُرَبِّيهَا لَهُ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ فَصِيلَهُ ‏"‏ ‏.‏\hadithno{1842}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa'eed bin Yasar narrated that:he heard Abu Hurairah say: “The Messenger of Allah said: 'No one gives charity from good sources - for Allah does not accept anything but that which is good - but the Most Merciful takes it in His right hand, even if it is a date, and it flourishes in the Hand of the Most Merciful until it becomes bigger than a mountain and he tends it as anyone of you would tend to his colt (i.e., young pony) or his young (weaned) camel.'”}}
\hadithdefcmd{ibnmajah}{1843}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ سَيُكَلِّمُهُ رَبُّهُ لَيْسَ بَيْنَهُ وَبَيْنَهُ تَرْجُمَانٌ فَيَنْظُرُ أَمَامَهُ فَتَسْتَقْبِلُهُ النَّارُ وَيَنْظُرُ عَنْ أَيْمَنَ مِنْهُ فَلاَ يَرَى إِلاَّ شَيْئًا قَدَّمَهُ وَيَنْظُرُ عَنْ أَشْأَمَ مِنْهُ فَلاَ يَرَى إِلاَّ شَيْئًا قَدَّمَهُ فَمَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَتَّقِيَ النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{1843}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Adi bin Hatim narrated that:the Messenger of Allah said: “Each one of you will be spoken to by his lord, with no mediator between them. He will look in from of him and the fire will be facing him. He will look to his right and will not see anything but something that he had sent on before. He will look to his left and will not see anything but something that he had sent on before. Whoeever among you can save himself in Fire, even with half a date, let him do so.”}}
\hadithdefcmd{ibnmajah}{1844}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ عَوْنٍ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ أُمِّ الرَّائِحِ بِنْتِ صُلَيْعٍ، عَنْ سَلْمَانَ بْنِ عَامِرٍ الضَّبِّيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الصَّدَقَةُ عَلَى الْمِسْكِينِ صَدَقَةٌ وَهِيَ عَلَى ذِي الْقَرَابَةِ اثْنَتَانِ صَدَقَةٌ وَصِلَةٌ ‏"‏ ‏.‏\hadithno{1844}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Salman bin Amir Dabbi narrated that:the Messenger of Allah said: “Charity given to the poor is charity, and that given to a relative is two things: charity and upholding the ties of kinship.”}}
